@@ -194,12 +194,11 @@ void SearchEngine::resize()
 	{
 		case DisplayMode::Columns:
 			if (Config.titles_visibility)
-			{
 				w.setTitle(Display::Columns(w.getWidth()));
-				break;
-			}
+			break;
 		case DisplayMode::Classic:
 			w.setTitle("");
+			break;
 	}
 	hasToBeResized = 0;
 }
@@ -243,6 +242,7 @@ void SearchEngine::mouseButtonPressed(MEVENT me)
 
 bool SearchEngine::allowsSearching()
 {
+	ScopedUnfilteredMenu<SEItem> sunfilter(ReapplyFilter::Yes, w);
 	return w.rbegin()->value().isSong();
 }
 
@@ -425,6 +425,7 @@ void SearchEngine::reset()
 {
 	for (size_t i = 0; i < ConstraintsNumber; ++i)
 		itsConstraints[i].clear();
+	w.clearFilter();
 	w.reset();
 	Prepare();
 	Statusbar::print("Search state reset");
