@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008-2014 by Andrzej Rybczak                            *
+ *   Copyright (C) 2008-2017 by Andrzej Rybczak                            *
  *   electricityispower@gmail.com                                          *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -28,10 +28,12 @@
 #include <vector>
 #include <mpd/client.h>
 
+#include "curses/formatted_color.h"
+#include "curses/strbuffer.h"
 #include "enums.h"
 #include "format.h"
-#include "screen_type.h"
-#include "strbuffer.h"
+#include "lyrics_fetcher.h"
+#include "screens/screen_type.h"
 
 struct Column
 {
@@ -76,6 +78,7 @@ struct Configuration
 	std::string external_editor;
 	std::string system_encoding;
 	std::string execute_on_song_change;
+	std::string execute_on_player_state_change;
 	std::string lastfm_preferred_language;
 	std::wstring progressbar;
 	std::wstring visualizer_chars;
@@ -95,23 +98,28 @@ struct Configuration
 	NC::Buffer now_playing_prefix;
 	NC::Buffer now_playing_suffix;
 	NC::Buffer modified_item_prefix;
+	NC::Buffer current_item_prefix;
+	NC::Buffer current_item_suffix;
+	NC::Buffer current_item_inactive_column_prefix;
+	NC::Buffer current_item_inactive_column_suffix;
 
-	NC::Color color1;
-	NC::Color color2;
-	NC::Color empty_tags_color;
 	NC::Color header_color;
-	NC::Color volume_color;
-	NC::Color state_line_color;
-	NC::Color state_flags_color;
 	NC::Color main_color;
-	NC::Color main_highlight_color;
-	NC::Color progressbar_color;
-	NC::Color progressbar_elapsed_color;
 	NC::Color statusbar_color;
-	NC::Color alternative_ui_separator_color;
-	NC::Color active_column_color;
 
-	std::vector<NC::Color> visualizer_colors;
+	NC::FormattedColor color1;
+	NC::FormattedColor color2;
+	NC::FormattedColor empty_tags_color;
+	NC::FormattedColor volume_color;
+	NC::FormattedColor state_line_color;
+	NC::FormattedColor state_flags_color;
+	NC::FormattedColor progressbar_color;
+	NC::FormattedColor progressbar_elapsed_color;
+	NC::FormattedColor player_state_color;
+	NC::FormattedColor statusbar_time_color;
+	NC::FormattedColor alternative_ui_separator_color;
+
+	std::vector<NC::FormattedColor> visualizer_colors;
 	VisualizerType visualizer_type;
 
 	NC::Border window_border;
@@ -148,10 +156,12 @@ struct Configuration
 	bool display_bitrate;
 	bool display_remaining_time;
 	bool ignore_leading_the;
+	bool ignore_diacritics;
 	bool block_search_constraints_change;
 	bool use_console_editor;
 	bool use_cyclic_scrolling;
 	bool ask_before_clearing_playlists;
+	bool ask_before_shuffling_playlists;
 	bool mouse_support;
 	bool mouse_list_scroll_whole_page;
 	bool visualizer_in_stereo;
@@ -163,7 +173,7 @@ struct Configuration
 	bool generate_win32_compatible_filenames;
 	bool ask_for_locked_screen_width_part;
 	bool allow_for_physical_item_deletion;
-	bool progressbar_boldness;
+	bool media_library_albums_split_by_date;
 	bool startup_slave_screen_focus;
 
 	unsigned mpd_connection_timeout;
@@ -180,22 +190,26 @@ struct Configuration
 	boost::posix_time::seconds playlist_disable_highlight_delay;
 	boost::posix_time::seconds visualizer_sync_interval;
 
-	double visualizer_sample_multiplier;
 	double locked_screen_width_part;
 
 	size_t selected_item_prefix_length;
 	size_t selected_item_suffix_length;
 	size_t now_playing_prefix_length;
 	size_t now_playing_suffix_length;
+	size_t current_item_prefix_length;
+	size_t current_item_suffix_length;
+	size_t current_item_inactive_column_prefix_length;
+	size_t current_item_inactive_column_suffix_length;
 
 	ScreenType startup_screen_type;
 	boost::optional<ScreenType> startup_slave_screen_type;
-	std::list<ScreenType> screen_sequence;
+	std::vector<ScreenType> screen_sequence;
 
 	SortMode browser_sort_mode;
+
+	LyricsFetchers lyrics_fetchers;
 };
 
 extern Configuration Config;
 
 #endif // NCMPCPP_SETTINGS_H
-
