@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008-2014 by Andrzej Rybczak                            *
+ *   Copyright (C) 2008-2017 by Andrzej Rybczak                            *
  *   electricityispower@gmail.com                                          *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -18,6 +18,7 @@
  *   51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.              *
  ***************************************************************************/
 
+#include <algorithm>
 #include <boost/algorithm/string/replace.hpp>
 #include "utility/html.h"
 
@@ -58,33 +59,38 @@ void unescapeHtmlEntities(std::string &s)
 	boost::replace_all(s, "&lt;", "<");
 	boost::replace_all(s, "&nbsp;", " ");
 	boost::replace_all(s, "&quot;", "\"");
+	boost::replace_all(s, "&ndash;", "–");
+	boost::replace_all(s, "&mdash;", "—");
 }
 
 void stripHtmlTags(std::string &s)
 {
-	bool erase = 0;
+	// Erase newlines so they don't duplicate with HTML ones.
+	s.erase(std::remove_if(s.begin(), s.end(), [](char c) {
+				return c == '\n' || c == '\r';
+			}), s.end());
+
+	bool is_newline;
 	for (size_t i = s.find("<"); i != std::string::npos; i = s.find("<"))
 	{
-		size_t j = s.find(">", i)+1;
-		if (s.compare(i, j-i, "<p>") == 0 || s.compare(i, j-i, "</p>") == 0)
-			s.replace(i, j-i, "\n");
+		size_t j = s.find(">", i);
+		if (j != std::string::npos)
+		{
+			++j;
+			is_newline
+				=  s.compare(i, std::min<size_t>(3, j-i), "<p ") == 0
+				|| s.compare(i, j-i, "<p>") == 0
+				|| s.compare(i, j-i, "</p>") == 0
+				|| s.compare(i, j-i, "<br>") == 0
+				|| s.compare(i, j-i, "<br/>") == 0
+				|| s.compare(i, std::min<size_t>(4, j-i), "<br ") == 0;
+			if (is_newline)
+				s.replace(i, j-i, "\n");
+			else
+				s.replace(i, j-i, "");
+		}
 		else
-			s.replace(i, j-i, "");
+			break;
 	}
 	unescapeHtmlEntities(s);
-	for (size_t i = 0; i < s.length(); ++i)
-	{
-		if (erase)
-		{
-			s.erase(s.begin()+i);
-			erase = 0;
-		}
-		if (s[i] == 13) // ascii code for windows line ending, get rid of this shit
-		{
-			s[i] = '\n';
-			erase = 1;
-		}
-		else if (s[i] == '\t')
-			s[i] = ' ';
-	}
-}
\ No newline at end of file
+}
